pub enum InstallOutcome {
Binary {
agent_id: String,
path: PathBuf,
},
PackageManager {
agent_id: String,
method: InstallMethod,
package: String,
},
}Expand description
Outcome data that is printed by the install subcommand.
Variants
Binary
A binary archive was downloaded and copied under the user bin directory.
Fields
PackageManager
A package manager (npm or uv) installed a wrapper on behalf of the agent.