pub struct AgentDistribution {
pub binary: Option<BinaryDistribution>,
pub npx: Option<NpxDistribution>,
pub uvx: Option<UvxDistribution>,
}Expand description
Distribution channels that may be published for an agent.
Fields
binary: Option<BinaryDistribution>Platform-specific binaries that can be downloaded and executed directly.
npx: Option<NpxDistribution>npx package metadata when the agent ships as an npm package.
uvx: Option<UvxDistribution>uvx package metadata for uv installed agents.
Implementations
Sourceimpl AgentDistribution
impl AgentDistribution
Sourcepub fn has_distribution_source(&self) -> bool
pub fn has_distribution_source(&self) -> bool
Returns true if the agent references at least one install/run source.